Struct bootloader::boot_info::FrameBuffer

source ·
#[repr(C)]
pub struct FrameBuffer { /* private fields */ }
A pixel-based framebuffer that controls the screen output.

Implementations

source

impl FrameBuffer

source

pub fn buffer(&self) -> &[u8]

Returns the raw bytes of the framebuffer as slice.

source

pub fn buffer_mut(&mut self) -> &mut [u8]

Returns the raw bytes of the framebuffer as mutable slice.

source

pub fn info(&self) -> FrameBufferInfo

Returns layout and pixel format information of the framebuffer.