Struct bootloader::boot_info::FrameBufferInfo
source · [−]#[repr(C)]pub struct FrameBufferInfo {
pub byte_len: usize,
pub horizontal_resolution: usize,
pub vertical_resolution: usize,
pub pixel_format: PixelFormat,
pub bytes_per_pixel: usize,
pub stride: usize,
}Expand description
Describes the layout and pixel format of a framebuffer.
Fields
byte_len: usizeThe total size in bytes.
horizontal_resolution: usizeThe width in pixels.
vertical_resolution: usizeThe height in pixels.
pixel_format: PixelFormatThe color format of each pixel.
bytes_per_pixel: usizeThe number of bytes per pixel.
stride: usizeNumber of pixels between the start of a line and the start of the next.
Some framebuffers use additional padding at the end of a line, so this
value might be larger than horizontal_resolution. It is
therefore recommended to use this field for calculating the start address of a line.