Struct bootloader::boot_info::MemoryRegions
source · [−]#[repr(C)]pub struct MemoryRegions { /* private fields */ }Expand description
FFI-safe slice of MemoryRegion structs, semantically equivalent to
&'static mut [MemoryRegion].
This type implements the Deref and DerefMut
traits, so it can be used like a &mut [MemoryRegion] slice. It also implements From
and Into for easy conversions from and to &'static mut [MemoryRegion].