Macro bootloader::entry_point
source · [−]macro_rules! entry_point {
($path:path) => { ... };
}Expand description
Defines the entry point function.
The function must have the signature fn(&'static mut BootInfo) -> !.
This macro just creates a function named _start, which the linker will use as the entry
point. The advantage of using this macro instead of providing an own _start function is
that the macro ensures that the function and argument types are correct.