Struct bootloader::boot_info::FrameBuffer
source · #[repr(C)]pub struct FrameBuffer { /* private fields */ }Expand description
A pixel-based framebuffer that controls the screen output.
Implementations
sourceimpl FrameBuffer
impl FrameBuffer
sourcepub fn buffer_mut(&mut self) -> &mut [u8]
pub fn buffer_mut(&mut self) -> &mut [u8]
Returns the raw bytes of the framebuffer as mutable slice.
sourcepub fn info(&self) -> FrameBufferInfo
pub fn info(&self) -> FrameBufferInfo
Returns layout and pixel format information of the framebuffer.